Charlie Marsh
@charliermarsh
Switching to codegen-units = 1 made the uv build ~50% faster, cut peak memory by 67%, and reduced binary size by 17%.
I was really surprised by this... Increasing the number of codegen units typically _improves_ build times.
I was really surprised by this... Increasing the number of codegen units typically _improves_ build times.
16 215